import React, { Component } from "react";
import DatePicker,  {registerLocale} from "react-datepicker";
import {
    Label, Input, FormGroup, FormFeedback
} from 'reactstrap';
import PropTypes from 'prop-types';
import locale from 'date-fns/locale/es';
import '../common/css/datefield.css';

registerLocale('es', locale);
class DateField extends Component {

    static propTypes = {
        maxDate: PropTypes.string,
        minDate: PropTypes.string,
        value: PropTypes.string,
        helpText: PropTypes.string,
        error: PropTypes.shape(),
        name: PropTypes.string.isRequired,
        label: PropTypes.string.isRequired,
        onChange: PropTypes.func.isRequired
    };

    static defaultProps = {
        format: 'DD/MM/YYYY',
        minDate: null,
        maxDate: null,
        value: null,
        label: null,
        onChange: null,
        error: {
            status: null
        }
    };
    constructor(props) {
        super(props);
        this.state = {
            startDate:this.props.value ? ((new Date(this.props.value)).setDate((new Date(this.props.value).getDate()+1)) ) : new Date()
        };
    }
    handleChange = startDate => {
        this.setState({
            startDate
        });
        if (this.props.value === formattedDate(startDate)) {
            return;
        }
            const { name, type} = this.props;
            const event = {target:{type:type, value:formattedDate(startDate), name:name}}
            //TODO replace this line to avoid scalation issues
            this.props.onChange(event);
    };
    render() {
        const styles = {
            flex: {
                display: 'flex',
                flexDirection: 'column',
                margin: '0px'
            },
            noPadding: {
                margin:'0px',
                padding:'0px'
            },
            styleValid: {
                width: '100%',
                height: '0px',
                paddingTop: 0.25,
                fontSize: '80%',
                color: '#43a047'
            }
        }
        const { name, label, dateFormat, minDate, maxDate , helpText, error, value
} = this.props;
    const {startDate} = this.state;
        return (
            <FormGroup style={styles.flex}>
                <Label style={styles.noPadding}>{label}</Label>
                <DatePicker
                    placeholderText={helpText}
                    portalId="root-portal"
                    fixedHeight
                    showMonthDropdown
                    key={"es"}
                    locale={"es"}
                    dateFormat={dateFormat}
                    minDate={new Date(minDate)}
                    maxDate={new Date(maxDate)}
                    selected={startDate}
                    onChange={this.handleChange}
                    yearDropdownItemNumber={15}
                    scrollableYearDropdown
                    customInput={
                                <Input
                                    valid={error.status === 'valid' ? true : null}
                                    invalid={error.status === 'invalid' ? true : null}
                                    id={name}
                                    placeholder={helpText}
                                    name={name}
                                    value={value}
                                    minLength={10}
                                    maxLength={10}
                                    autoComplete="off"
                                />
                                }
                />
                <FormFeedback valid={(error.status === 'valid') ? true : null}>
                    {error.message}
                </FormFeedback>
            </FormGroup>
)}
}
function formattedDate(d ) {
    return [d.getFullYear(), d.getMonth()+1,  d.getDate()]
        .map(n => n < 10 ? `0${n}` : `${n}`).join('-');
}
export default DateField;
