import React, {Fragment} from 'react';
import PropTypes from 'prop-types';
import Select, {components} from 'react-select';
import {
    FormFeedback,
    FormGroup,
    FormText,
    Label,
    Tooltip,
    Row,
    Col
} from 'reactstrap';
import Loading from '../Loading';
import {TextField} from './index';
const customComponents = {
    NoOptionsMessage: props => (
        <Tooltip content="noMessageOption">
            <components.NoOptionsMessage {...props}>
                No se encontraron resultados&nbsp;
            </components.NoOptionsMessage>
            &nbsp;
        </Tooltip>
    )
};
const styles = {
    noPadding: {
        margin: '0px',
        padding: '0px'
    },
    styleInvalid: {
        width: '100%',
        height: '0px',
        paddingTop: 0.25,
        fontSize: '80%',
        color: '#dc3545'
    },
    styleValid: {
        width: '100%',
        height: '0px',
        paddingTop: 0.25,
        fontSize: '80%',
        color: '#43a047'
    }
}

const SelectInput = ({
                         label,
                         control,
                         defaultOption,
                         disabled,
                         filterOption,
                         getValue,
                         onChange,
                         onChangeOthers,
                         onInputChange,
                         options,
                         placeholder,
                         value,
                         valueOthers,
                         searching,
                         helpText,
                         error,
                         supportsWriteOthers
                     }) => (
    <FormGroup>
        <Row style={styles.noPadding}>
            <Col style={styles.noPadding}>
                <Fragment>
                    <Label>{label}</Label>
                    <Select
                        id={control}
                        value={getValue ? getValue(value, options) : value}
                        defaultValue={defaultOption ? {value: '', label: '[Todos]'} : false}
                        onChange={onChange}
                        onInputChange={onInputChange}
                        options={options}
                        components={customComponents}
                        filterOption={filterOption}
                        isSearchable
                        isClearable
                        isDisabled={disabled}
                        placeholder={placeholder}
                        clearValueText="Limpiar Filtro"
                        isLoading={searching}
                    />
                    {searching && (
                        <Loading
                            label="Estamos buscando tu consulta"
                        />
                    )}
                    <p style={error.status==='valid' ?  styles.styleValid : styles.styleInvalid}>
                        {error.message}
                    </p>
                    <FormText style={{paddingBottom: '11.25px'}}>{helpText}</FormText>
                </Fragment>
            </Col>
            {
                supportsWriteOthers && (
                    <div>
                        &nbsp;&nbsp;
                    </div>
                )
            }
            {supportsWriteOthers  && (
                <Col style={styles.noPadding}>
                    <TextField
                        name={`${control}Others`}
                        label={`Otro ${label}`}
                        value={valueOthers}
                        helpText={null}
                        disabled={value.value !== 'idAnother'}
                        onChange={e => onChangeOthers(e)}
                        error={error}
                    />
                </Col>
            )}
        </Row>
    </FormGroup>
);

SelectInput.propTypes = {
    label: PropTypes.string.isRequired,
    control: PropTypes.string.isRequired,
    options: PropTypes.arrayOf(PropTypes.shape({})).isRequired,
    onChange: PropTypes.func.isRequired,
    onChangeOthers: PropTypes.func.isRequired,
    valueOthers: PropTypes.string,
    value: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.number
    ]),
    onInputChange: PropTypes.func,
    getValue: PropTypes.func,
    defaultOption: PropTypes.bool,
    placeholder: PropTypes.string,
    disabled: PropTypes.bool,
    filterOption: PropTypes.oneOfType([
        PropTypes.any
    ]),
    searching: PropTypes.bool,
    helpText: PropTypes.bool,
    error: PropTypes.shape
};

SelectInput.defaultProps = {
    defaultOption: false,
    placeholder: '[Seleccione]',
    value: '',
    valueOthers: '',
    onInputChange: null,
    getValue: null,
    disabled: false,
    filterOption: null,
    searching: false,
    helpText: null,
    error: {
        status: null
    }
};

export default SelectInput;
